InventoryState class

Constructors

InventoryState(Map<String, int> stocks)
const
InventoryState.initial()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stocks Map<String, int>
final

Methods

copyWithStock(String productId, int quantity) InventoryState
getQuantity(String productId) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited