OrderState class

Constructors

OrderState(Map<String, ReplayOrder> orders)
const
OrderState.initial()

Properties

hashCode int
The hash code for this object.
no setterinherited
orders Map<String, ReplayOrder>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOrder(ReplayOrder order) OrderState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited