ReplayAssignment class

Constructors

ReplayAssignment({required String id, required String orderId, required String agentId, required String status})

Properties

agentId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
orderId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

copyWith({String? status}) ReplayAssignment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited