LoyaltyRewardEarned class

Constructors

LoyaltyRewardEarned({required String accountId, required String rewardType, required double amount, required DateTime earnedAt})

Properties

accountId String
final
amount double
final
earnedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
rewardType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited