OrderPlaced class
- Implemented types
Constructors
- OrderPlaced({required String orderId, required String customerId, double totalAmount = 0.0, required DateTime occurredAt})
Properties
- customerId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- occurredAt → DateTime
-
final
- orderId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalAmount → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited