ReplayOrder class
Constructors
- ReplayOrder({required String id, required String customerId, required DateTime placedAt})
Properties
- customerId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- placedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited