ReplayState class
Constructors
- ReplayState({required InventoryState inventory, required OrderState ordering, required DeliveryState delivery, required LoyaltyState loyalty})
-
const
- ReplayState.initial()
Properties
- delivery → DeliveryState
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inventory → InventoryState
-
final
- loyalty → LoyaltyState
-
final
- ordering → OrderState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InventoryState? inventory, OrderState? ordering, DeliveryState? delivery, LoyaltyState? loyalty}) → ReplayState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited